# Copyright 2021- Le Filament (https://le-filament.com)
# License AGPL-3.0 or later (http://www.gnu.org/licenses/agpl.html)

from odoo import api, fields, models


class NichoirsStatYear(models.Model):
    _name = "nichoirs.stat.year"
    _description = "Statistiques de ventes nichoirs"
    _order = "year DESC"

    # ------------------------------------------------------
    # Fields declaration
    # ------------------------------------------------------
    categ_id = fields.Many2one("product.public.category", "Catégorie", required=True)
    year = fields.Integer("Année")
    product_qty = fields.Integer("Nombre d'articles vendus")
    coeff_year = fields.Integer(
        "Coefficient calculé en fonction de l'année",
        compute="_compute_coeff_year",
        store=True,
        default=1,
    )
    nichoirs_proprata_qty = fields.Integer(
        "Nombre de nichoirs",
        compute="_compute_nichoirs_proprata_qty",
        store=True,
        default=0,
    )

    # ------------------------------------------------------
    # SQL Constraints
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Default methods
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Computed fields / Search Fields
    # ------------------------------------------------------
    @api.depends("year")
    def _compute_coeff_year(self):
        for res in self:
            if res.year:
                res.coeff_year = (fields.Date.today().year - res.year) + 1

    @api.depends("product_qty", "coeff_year")
    def _compute_nichoirs_proprata_qty(self):
        for res in self:
            if res.product_qty:
                res.nichoirs_proprata_qty = res.product_qty * res.coeff_year
                res.categ_id.update_qty()

    # ------------------------------------------------------
    # Onchange / Constraints
    # ------------------------------------------------------

    # ------------------------------------------------------
    # CRUD methods (ORM overrides)
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Actions
    # ------------------------------------------------------

    # ------------------------------------------------------
    # Business methods
    # ------------------------------------------------------
